pub struct IOPProver { /* private fields */ }Expand description
IOP prover for a particular constraint system.
This struct encapsulates the constraint system and pre-computed keys,
providing the core proving logic independent of the specific IOP compilation strategy.
Most users should use Prover instead, which wraps this with a BaseFold compiler.
Implementations
Sourceimpl IOPProver
impl IOPProver
Sourcepub fn new(iop_verifier: IOPVerifier, key_collection: KeyCollection) -> Self
pub fn new(iop_verifier: IOPVerifier, key_collection: KeyCollection) -> Self
Constructs an IOP prover from an IOP verifier and pre-computed keys.
Sourcepub const fn constraint_system(&self) -> &ConstraintSystem
pub const fn constraint_system(&self) -> &ConstraintSystem
Returns the constraint system.
Sourcepub const fn key_collection(&self) -> &KeyCollection
pub const fn key_collection(&self) -> &KeyCollection
Returns a reference to the KeyCollection.
This can be used to serialize the KeyCollection for later use.
Sourcepub fn prove<A, P, Channel>(
&self,
witness: &ValueVec,
channel: &mut Channel,
alloc: &A,
) -> Result<(), Error>where
A: Allocator,
P: PackedField<Scalar = B128>,
Channel: IOPProverChannel<P, A> + WordIPProverChannel<B128, Word = Word>,
pub fn prove<A, P, Channel>(
&self,
witness: &ValueVec,
channel: &mut Channel,
alloc: &A,
) -> Result<(), Error>where
A: Allocator,
P: PackedField<Scalar = B128>,
Channel: IOPProverChannel<P, A> + WordIPProverChannel<B128, Word = Word>,
Proves using an IOP channel interface.
This is the core proving logic, independent of the specific IOP compilation strategy.
For most users, Prover::prove is the simpler interface.