pub struct Prover<P, H>where
P: PackedField<Scalar = B128>,
H: ParallelHashSuite,{ /* private fields */ }Expand description
Struct for proving instances of a particular constraint system.
The Self::setup constructor pre-processes reusable structures for proving instances of the
given constraint system. Then Self::prove is called one or more times with individual
instances.
Implementations
Sourceimpl<P, H> Prover<P, H>
impl<P, H> Prover<P, H>
Sourcepub fn setup(verifier: Verifier<H>) -> Result<Self, Error>
pub fn setup(verifier: Verifier<H>) -> Result<Self, Error>
Constructs a prover corresponding to a constraint system verifier.
See Prover struct documentation for details.
Sourcepub fn setup_with_key_collection(
verifier: Verifier<H>,
key_collection: KeyCollection,
) -> Result<Self, Error>
pub fn setup_with_key_collection( verifier: Verifier<H>, key_collection: KeyCollection, ) -> Result<Self, Error>
Constructs a prover with a pre-built KeyCollection.
This allows loading a previously serialized KeyCollection to avoid the expensive key building phase during setup.
Sourcepub const fn iop_prover(&self) -> &IOPProver
pub const fn iop_prover(&self) -> &IOPProver
Returns a reference to the IOP prover.
Sourcepub const fn key_collection(&self) -> &KeyCollection
pub const fn key_collection(&self) -> &KeyCollection
Returns a reference to the KeyCollection.
This can be used to serialize the KeyCollection for later use.
pub fn prove<Challenger_: Challenger + Clone>( &self, witness: &ValueVec, transcript: &mut ProverTranscript<Challenger_>, ) -> Result<(), Error>